.. title:: Table of Contents

#########
qpsolvers
#########

.. **Release 1.7.1 -- October 2, 2021**

This library provides a unified interface to a wide array of Quadratic
Programming (QP) solvers available in Python.

.. toctree::

    installation.rst
    getting-started.rst
    supported-solvers.rst
